sqlglot._version API documentation

Edit on GitHub

# sqlglot._version

View Source

     1# file generated by setuptools_scm
     2# don't change, don't track in version control
     3TYPE_CHECKING = False
     4if TYPE_CHECKING:
     5    from typing import Tuple, Union
     6    VERSION_TUPLE = Tuple[Union[int, str], ...]
     7else:
     8    VERSION_TUPLE = object
     9
    10version: str
    11__version__: str
    12__version_tuple__: VERSION_TUPLE
    13version_tuple: VERSION_TUPLE
    14
    15__version__ = version = '22.3.0'
    16__version_tuple__ = version_tuple = (22, 3, 0)

TYPE_CHECKING = False
version: str = '22.3.0'
version_tuple: object = (22, 3, 0)